@@ -3,7 +3,6 @@ import contextlib
 import io
 import operator
 import re
-import warnings
 import weakref
 from posixpath import join as pjoin
 
@@ -170,8 +169,8 @@ class Backend(BaseSQLBackend):
     def hdfs_connect(self, *args, **kwargs):
         return hdfs_connect(*args, **kwargs)
 
-    def connect(
-        self,
+    def do_connect(
+        new_backend,
         host='localhost',
         port=21050,
         database='default',
@@ -240,7 +239,6 @@ class Backend(BaseSQLBackend):
         """
         import hdfs
 
-        new_backend = self.__class__()
         new_backend._kudu = None
         new_backend._temp_objects = set()
 
@@ -267,8 +265,6 @@ class Backend(BaseSQLBackend):
 
         new_backend._ensure_temp_db_exists()
 
-        return new_backend
-
     @property
     def version(self):
         cursor = self.raw_sql('select version()')
@@ -374,16 +370,11 @@ class Backend(BaseSQLBackend):
         tuples = cur.fetchall()
         return list(map(operator.itemgetter(0), tuples))
 
+    @util.deprecated(version='2.0', instead='a new connection to database')
     def set_database(self, name):
         # XXX The parent `Client` has a generic method that calls this same
         # method in the backend. But for whatever reason calling this code from
         # that method doesn't seem to work. Maybe `con` is a copy?
-        warnings.warn(
-            '`set_database` is deprecated and will be removed in a future '
-            'version of Ibis. Create a new connection to the desired database '
-            'instead',
-            FutureWarning,
-        )
         self.con.set_database(name)
 
     @property
