@@ -17,6 +17,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
 import pprint
 import re
@@ -25,14 +26,18 @@ from collections import namedtuple
 from contextlib import contextmanager
 from typing import Callable
 
+import ibis
+
 DeprecatedOption = namedtuple('DeprecatedOption', 'key msg rkey removal_ver')
 RegisteredOption = namedtuple(
     'RegisteredOption', 'key defval doc validator cb'
 )
 
 _deprecated_options = {}  # holds deprecated option metdata
-_registered_options = {}  # holds registered option metdata
-_global_config = {}  # holds the current values for registered options
+# holds registered option metdata
+_registered_options: dict[str, RegisteredOption] = {}
+# holds the current values for registered options
+_global_config: dict[str, RegisteredOption] = {}
 _reserved_keys = ['all']  # keys which have a special meaning
 
 
@@ -200,7 +205,17 @@ class DictWrapper:
         try:
             v = self.d[key]
         except KeyError as e:
-            raise AttributeError(*e.args)
+            # See if the options doesn't exist because it's from a backend
+            # not yet loaded. Try to load, and try the option again.
+            try:
+                getattr(ibis, key)
+            except Exception:
+                raise AttributeError(*e.args)
+            else:
+                try:
+                    v = self.d[key]
+                except KeyError as e:
+                    raise AttributeError(*e.args)
 
         if isinstance(v, dict):
             return DictWrapper(v, prefix)
@@ -233,7 +248,7 @@ class CallableDynamicDoc:
         return self.__func__(*args, **kwds)
 
     @property
-    def __doc__(self) -> str:
+    def __doc__(self):
         """Create automatically a documentation using a template.
 
         Returns
@@ -541,7 +556,9 @@ def _select_options(pat: str) -> list:
     return [k for k in keys if re.search(pat, k, re.I)]
 
 
-def _get_root(key: str) -> tuple:
+def _get_root(
+    key: str,
+) -> tuple[RegisteredOption | dict[str, RegisteredOption], str]:
     """Return the parent node of an option.
 
     Parameters
@@ -556,7 +573,7 @@ def _get_root(key: str) -> tuple:
     cursor = _global_config
     for p in path[:-1]:
         cursor = cursor[p]
-    return cursor, path[-1]
+    return (cursor, path[-1])
 
 
 def _is_deprecated(key: str) -> bool:
@@ -669,7 +686,7 @@ def _build_option_description(k: str) -> str:
     o = _get_registered_option(k)
     d = _get_deprecated_option(k)
 
-    buf = ['{} '.format(k)]
+    buf = [f'{k} ']
 
     if o.doc:
         doc = '\n'.join(o.doc.strip().splitlines())
@@ -688,7 +705,7 @@ def _build_option_description(k: str) -> str:
     if d:
         buf.append(
             '\n    (Deprecated{})'.format(
-                ', use `{}` instead.'.format(d.rkey) if d.rkey else ''
+                f', use `{d.rkey}` instead.' if d.rkey else ''
             )
         )
 
@@ -696,7 +713,9 @@ def _build_option_description(k: str) -> str:
     return ''.join(buf)
 
 
-def pp_options_list(keys: str, width: int = 80, _print: bool = False) -> str:
+def pp_options_list(
+    keys: list[str], width: int = 80, _print: bool = False
+) -> str | None:
     """
     Build a concise listing of available options, grouped by prefix.
 
@@ -738,6 +757,7 @@ def pp_options_list(keys: str, width: int = 80, _print: bool = False) -> str:
     s = '\n'.join(ls)
     if _print:
         print(s)
+        return None
     else:
         return s
 
@@ -775,7 +795,7 @@ def config_prefix(prefix):
 
     def wrap(func):
         def inner(key, *args, **kwds):
-            pkey = '%s.%s' % (prefix, key)
+            pkey = f'{prefix}.{key}'
             return func(pkey, *args, **kwds)
 
         return inner
