@@ -1,8 +1,7 @@
 import itertools
 import os
-import warnings
 import webbrowser
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Dict, Optional
 
 import numpy as np
 
@@ -205,7 +204,9 @@ class Expr:
         """
         from ibis.backends.base import BaseBackend
 
-        seen_backends = set()
+        seen_backends: Dict[
+            str, BaseBackend
+        ] = {}  # key is backend.db_identity
 
         stack = [self.op()]
         seen = set()
@@ -218,11 +219,12 @@ class Expr:
 
                 for arg in node.flat_args():
                     if isinstance(arg, BaseBackend):
-                        seen_backends.add(arg)
+                        if arg.db_identity not in seen_backends:
+                            seen_backends[arg.db_identity] = arg
                     elif isinstance(arg, ir.Expr):
                         stack.append(arg.op())
 
-        return list(seen_backends)
+        return list(seen_backends.values())
 
     def _find_backend(self):
         backends = self._find_backends()
@@ -292,15 +294,11 @@ class Expr:
             self, limit=limit, timecontext=timecontext, params=params
         )
 
+    @util.deprecated(version='2.0', instead='compile & catch TranslationError')
     def verify(self):
         """
         Returns True if expression can be compiled to its attached client
         """
-        warnings.warn(
-            '`verify` is deprecated, use `compile` and capture the '
-            '`TranslationError` exception instead',
-            FutureWarning,
-        )
         try:
             self.compile()
         except Exception:
@@ -314,54 +312,6 @@ class Expr:
         return self._arg.equals(other._arg, cache=cache)
 
 
-class ExprList(Expr):
-    def _type_display(self):
-        return ', '.join(expr._type_display() for expr in self.exprs())
-
-    def exprs(self):
-        return self.op().exprs
-
-    def names(self):
-        return [x.get_name() for x in self.exprs()]
-
-    def types(self):
-        return [x.type() for x in self.exprs()]
-
-    def schema(self):
-        import ibis.expr.schema as sch
-
-        return sch.Schema(self.names(), self.types())
-
-    def rename(self, f):
-        import ibis.expr.operations as ops
-
-        new_exprs = [x.name(f(x.get_name())) for x in self.exprs()]
-        return ops.ExpressionList(new_exprs).to_expr()
-
-    def prefix(self, value):
-        return self.rename(lambda x: value + x)
-
-    def suffix(self, value):
-        return self.rename(lambda x: x + value)
-
-    def concat(self, *others):
-        """
-        Concatenate expression lists
-
-        Returns
-        -------
-        combined : ExprList
-        """
-        import ibis.expr.operations as ops
-
-        exprs = list(self.exprs())
-        for o in others:
-            if not isinstance(o, ExprList):
-                raise TypeError(o)
-            exprs.extend(o.exprs())
-        return ops.ExpressionList(exprs).to_expr()
-
-
 # ---------------------------------------------------------------------
 # Helper / factory functions
 
@@ -418,6 +368,21 @@ class ScalarExpr(ValueExpr):
     def _type_display(self):
         return str(self.type())
 
+    def to_projection(self):
+        """
+        Promote this column expression to a table projection
+        """
+        roots = self.op().root_tables()
+        if len(roots) > 1:
+            raise com.RelationError(
+                'Cannot convert scalar expression '
+                'involving multiple base table references '
+                'to a projection'
+            )
+
+        table = TableExpr(roots[0])
+        return table.projection([self])
+
 
 class ColumnExpr(ValueExpr):
     def _type_display(self):
@@ -605,7 +570,7 @@ class TableExpr(Expr):
         """
         import ibis.expr.operations as ops
 
-        ref = ops.TableColumn(name, self)
+        ref = ops.TableColumn(self, name)
         return ref.to_expr()
 
     @property
@@ -1287,41 +1252,10 @@ def literal(value, type=None):
     if dtype is dt.null:
         return null().cast(dtype)
     else:
+        value = dt._normalize(dtype, value)
         return ops.Literal(value, dtype=dtype).to_expr()
 
 
-def sequence(values):
-    """
-    Wrap a list of Python values as an Ibis sequence type
-
-    Parameters
-    ----------
-    values : list
-      Should all be None or the same type
-
-    Returns
-    -------
-    seq : Sequence
-    """
-    import ibis.expr.operations as ops
-
-    return ops.ValueList(values).to_expr()
-
-
-def as_value_expr(val):
-    import pandas as pd
-
-    if not isinstance(val, Expr):
-        if isinstance(val, (tuple, list)):
-            val = sequence(val)
-        elif isinstance(val, pd.Series):
-            val = sequence(list(val))
-        else:
-            val = literal(val)
-
-    return val
-
-
 def array(values):
     """Create an array expression.
 
