@@ -220,19 +220,6 @@ SELECT 1 + 2 AS `tmp`"""
             result = Compiler.to_sql(expr)
             assert result == expected
 
-    def test_expr_list_no_table_refs(self):
-        exlist = ibis.api.expr_list(
-            [
-                ibis.literal(1).name('a'),
-                ibis.now().name('b'),
-                ibis.literal(2).log().name('c'),
-            ]
-        )
-        result = Compiler.to_sql(exlist)
-        expected = """\
-SELECT 1 AS `a`, now() AS `b`, ln(2) AS `c`"""
-        assert result == expected
-
     def test_isnull_case_expr_rewrite_failure(self):
         # #172, case expression that was not being properly converted into an
         # aggregation
@@ -1091,17 +1078,20 @@ WHERE (`timestamp_col` < date_add(cast({} as timestamp), INTERVAL 3 MONTH)) AND
         # TODO(cpcloud): We should be able to flatten the second subquery into
         # the first
         expected = """\
-SELECT t0.*
+SELECT *
 FROM (
-  SELECT *, avg(`arrdelay`) OVER (PARTITION BY `dest`) AS `dest_avg`,
-         `arrdelay` - avg(`arrdelay`) OVER (PARTITION BY `dest`) AS `dev`
+  SELECT t1.*
   FROM (
-    SELECT `arrdelay`, `dest`
-    FROM airlines
-  ) t2
+    SELECT *, avg(`arrdelay`) OVER (PARTITION BY `dest`) AS `dest_avg`,
+           `arrdelay` - avg(`arrdelay`) OVER (PARTITION BY `dest`) AS `dev`
+    FROM (
+      SELECT `arrdelay`, `dest`
+      FROM airlines
+    ) t3
+  ) t1
+  WHERE t1.`dev` IS NOT NULL
 ) t0
-WHERE t0.`dev` IS NOT NULL
-ORDER BY t0.`dev` DESC
+ORDER BY `dev` DESC
 LIMIT 10"""
         assert result == expected
 
@@ -1710,14 +1700,14 @@ FROM t0
             'airlines',
         )
 
-        dests = ['ORD', 'JFK', 'SFO']
-        dests_formatted = repr(tuple(set(dests)))
+        dests = {'ORD', 'JFK', 'SFO'}
+        dests_formatted = repr(tuple(dests))
         delay_filter = airlines.dest.topk(10, by=airlines.arrdelay.mean())
         t = airlines[airlines.dest.isin(dests)]
         expr = t[delay_filter].group_by('origin').size()
 
         result = Compiler.to_sql(expr)
-        expected = """\
+        expected = f"""\
 SELECT t0.`origin`, count(*) AS `count`
 FROM airlines t0
   LEFT SEMI JOIN (
@@ -1731,10 +1721,8 @@ FROM airlines t0
     LIMIT 10
   ) t1
     ON t0.`dest` = t1.`dest`
-WHERE t0.`dest` IN {}
-GROUP BY 1""".format(
-            dests_formatted
-        )
+WHERE t0.`dest` IN {dests_formatted}
+GROUP BY 1"""
 
         assert result == expected
 
@@ -2366,8 +2354,7 @@ def test_pushdown_with_or():
     expected = """\
 SELECT *
 FROM functional_alltypes
-WHERE (`double_col` > 3.14) AND
-      (locate('foo', `string_col`) - 1 >= 0) AND
+WHERE ((`double_col` > 3.14) AND (locate('foo', `string_col`) - 1 >= 0)) AND
       (((`int_col` - 1) = 0) OR (`float_col` <= 1.34))"""
     assert result == expected
 
