@@ -484,32 +484,29 @@ class TestSQLAlchemySelect(unittest.TestCase, ExprTestCases):
     def test_lower_projection_sort_key(self):
         expr = self._case_subquery_aliased()
 
-        s1 = self._get_sqla('star1').alias('t2')
-        s2 = self._get_sqla('star2').alias('t1')
+        t3 = self._get_sqla('star1').alias('t3')
+        t2 = self._get_sqla('star2').alias('t2')
+        t4 = (
+            sa.select([t3.c.foo_id, F.sum(t3.c.f).label('total')])
+            .group_by(t3.c.foo_id)
+            .alias('t4')
+        )
+        t1 = (
+            sa.select([t4.c.foo_id, t4.c.total, t2.c.value1])
+            .select_from(t4.join(t2, t4.c.foo_id == t2.c.foo_id))
+            .alias('t1')
+        )
+        t0 = (
+            sa.select([t1.c.foo_id, t1.c.total, t1.c.value1])
+            .where(t1.c.total > L(100))
+            .alias('t0')
+        )
+        expected = sa.select([t0.c.foo_id, t0.c.total, t0.c.value1]).order_by(
+            t0.c.total.desc()
+        )
 
         expr2 = expr[expr.total > 100].sort_by(ibis.desc('total'))
-
-        agged = (
-            sa.select([s1.c.foo_id, F.sum(s1.c.f).label('total')])
-            .group_by(s1.c.foo_id)
-            .alias('t3')
-        )
-
-        joined = agged.join(s2, agged.c.foo_id == s2.c.foo_id)
-        expected = sa.select([agged, s2.c.value1]).select_from(joined)
-
-        joined = agged.join(s2, agged.c.foo_id == s2.c.foo_id)
-        expected = sa.select([agged, s2.c.value1]).select_from(joined)
-
-        ex = expected.alias('t0')
-
-        expected2 = (
-            sa.select([ex])
-            .where(ex.c.total > L(100))
-            .order_by(ex.c.total.desc())
-        )
-
-        self._compare_sqla(expr2, expected2)
+        self._compare_sqla(expr2, expected)
 
     def test_exists(self):
         e1, e2 = self._case_exists()
@@ -625,10 +622,93 @@ class TestSQLAlchemySelect(unittest.TestCase, ExprTestCases):
 
         self._compare_sqla(expr, ex)
 
+    def test_where_correlated_subquery_with_join(self):
+        # GH3163
+        # ibis code
+        part = ibis.table([("p_partkey", "int64")], name="part")
+        partsupp = ibis.table(
+            [
+                ("ps_partkey", "int64"),
+                ("ps_supplycost", "float64"),
+                ("ps_suppkey", "int64"),
+            ],
+            name="partsupp",
+        )
+        supplier = ibis.table([("s_suppkey", "int64")], name="supplier")
+
+        q = part.join(partsupp, part.p_partkey == partsupp.ps_partkey)
+        q = q[
+            part.p_partkey,
+            partsupp.ps_supplycost,
+        ]
+        subq = partsupp.join(
+            supplier, supplier.s_suppkey == partsupp.ps_suppkey
+        )
+        subq = subq.projection([partsupp.ps_partkey, partsupp.ps_supplycost])
+        subq = subq[subq.ps_partkey == q.p_partkey]
+
+        expr = q[q.ps_supplycost == subq.ps_supplycost.min()]
+
+        # sqlalchemy code
+        part = sa.table("part", sa.column("p_partkey"))
+        supplier = sa.table("supplier", sa.column("s_suppkey"))
+        partsupp = sa.table(
+            "partsupp",
+            sa.column("ps_partkey"),
+            sa.column("ps_supplycost"),
+            sa.column("ps_suppkey"),
+        )
+
+        part_t1 = part.alias("t1")
+        partsupp_t2 = partsupp.alias("t2")
+
+        t0 = (
+            sa.select([part_t1.c.p_partkey, partsupp_t2.c.ps_supplycost])
+            .select_from(
+                part_t1.join(
+                    partsupp_t2,
+                    onclause=part_t1.c.p_partkey == partsupp_t2.c.ps_partkey,
+                )
+            )
+            .alias("t0")
+        )
+
+        partsupp_t2 = partsupp.alias("t2")
+        supplier_t5 = supplier.alias("t5")
+        t3 = (
+            sa.select([partsupp_t2.c.ps_partkey, partsupp_t2.c.ps_supplycost])
+            .select_from(
+                partsupp_t2.join(
+                    supplier_t5,
+                    onclause=supplier_t5.c.s_suppkey
+                    == partsupp_t2.c.ps_suppkey,
+                )
+            )
+            .alias("t3")
+        )
+
+        ex = (
+            sa.select([t0.c.p_partkey, t0.c.ps_supplycost])
+            .select_from(t0)
+            .where(
+                t0.c.ps_supplycost
+                == (
+                    sa.select([sa.func.min(t3.c.ps_supplycost).label("min")])
+                    .select_from(t3)
+                    .where(t3.c.ps_partkey == t0.c.p_partkey)
+                    .as_scalar()
+                )
+            )
+        )
+
+        self._compare_sqla(expr, ex)
+
     def _compare_sqla(self, expr, sqla):
         context = AlchemyContext(compiler=AlchemyCompiler)
-        result = AlchemyCompiler.to_sql(expr, context)
-        assert str(result.compile()) == str(sqla.compile())
+        result_sqla = AlchemyCompiler.to_sql(expr, context)
+        result = str(result_sqla.compile())
+        expected = str(sqla.compile())
+        assert result == expected
 
     def _to_sqla(self, table):
         return table.op().sqla_table
